==> biocViews_1.10.6.zip: PackageDetail-class.R <==
### Name: PackageDetail-class
### Title: Class "PackageDetail"
### Aliases: PackageDetail-class pdAuthorMaintainerInfo-class
###   pdVignetteInfo-class pdDownloadInfo-class pdDetailsInfo-class
###   pdDescriptionInfo-class pdVigsAndDownloads-class
###   htmlDoc,PackageDetail-method htmlFilename,PackageDetail-method
###   htmlValue,PackageDetail-method
###   htmlValue,pdAuthorMaintainerInfo-method
###   htmlValue,pdVignetteInfo-method htmlValue,pdDownloadInfo-method
###   htmlValue,pdDetailsInfo-method htmlValue,pdDescriptionInfo-method
###   htmlValue,pdVigsAndDownloads-method
### Keywords: classes

### ** Examples

pd <- new("PackageDetail",
          Package="MyFancyPackage",
          Version="1.2.3",
          Title="A Fancy Package",
          Description="This package does fancy things",
          Author="A. Coder",
          Maintainer="A. Coder <acoder@foo.bar.net>",
          Depends="methods",
          Imports="ASimplePackage",
          Suggests="MyDataPackage",
          biocViews="Infrastructure",
          vignettes="vignettes/MyFancyPackage/inst/doc/MFP1.pdf,\nvignettes/MyFancyPackage/inst/doc/MFP2.pdf",
          vignetteTitles="MFP1 Document,\nMFP2 Document",
          source.ver="src/contrib/MyFancyPackage_1.2.3.tar.gz",
          win.binary.ver="bin/windows/contrib/2.3/MyFancyPackage_1.2.2.zip",
          mac.binary.universal.ver="bin/macosx/universal/contrib/2.3/MyFancyPackage_1.2.3.tgz",
          mac.binary.leopard.ver="bin/macosx/leopard/contrib/2.3/MyFancyPackage_1.2.3.tgz",
          dependsOnMe=c("PackageThatExposesMe"),
          importsMe=c("AnEvenFancierPackage","AMuchFancierPackage"),
          suggestsMe="PackageThatUsesMeInVignette",
          reposRoot="http://foo.bar.org")

html <- htmlValue(pd)
pd

==> biocViews_1.12.3.zip: PackageDetail-class.R <==
### Name: PackageDetail-class
### Title: Class "PackageDetail"
### Aliases: PackageDetail-class pdAuthorMaintainerInfo-class
###   pdVignetteInfo-class pdDownloadInfo-class pdDetailsInfo-class
###   pdDescriptionInfo-class pdVigsAndDownloads-class
###   htmlDoc,PackageDetail-method htmlFilename,PackageDetail-method
###   htmlValue,PackageDetail-method
###   htmlValue,pdAuthorMaintainerInfo-method
###   htmlValue,pdVignetteInfo-method htmlValue,pdDownloadInfo-method
###   htmlValue,pdDetailsInfo-method htmlValue,pdDescriptionInfo-method
###   htmlValue,pdVigsAndDownloads-method
### Keywords: classes

### ** Examples

pd <- new("PackageDetail",
          Package="MyFancyPackage",
          Version="1.2.3",
          Title="A Fancy Package",
          Description="This package does fancy things",
          Author="A. Coder",
          Maintainer="A. Coder <acoder@foo.bar.net>",
          Depends="methods",
          Imports="ASimplePackage",
          Suggests="MyDataPackage",
          biocViews="Infrastructure",
          vignettes="vignettes/MyFancyPackage/inst/doc/MFP1.pdf,\nvignettes/MyFancyPackage/inst/doc/MFP2.pdf",
          vignetteScripts="vignettes/MyFancyPackage/inst/doc/MFP1.R\nvignettes/MyFancyPackage/inst/doc/MFP2.R",
          vignetteTitles="MFP1 Document,\nMFP2 Document",
          source.ver="src/contrib/MyFancyPackage_1.2.3.tar.gz",
          win.binary.ver="bin/windows/contrib/2.3/MyFancyPackage_1.2.2.zip",
          mac.binary.universal.ver="bin/macosx/universal/contrib/2.3/MyFancyPackage_1.2.3.tgz",
          mac.binary.leopard.ver="bin/macosx/leopard/contrib/2.3/MyFancyPackage_1.2.3.tgz",
          dependsOnMe=c("PackageThatExposesMe"),
          importsMe=c("AnEvenFancierPackage","AMuchFancierPackage"),
          suggestsMe="PackageThatUsesMeInVignette",
          reposRoot="http://foo.bar.org")

html <- htmlValue(pd)
pd
